/*
 * Stop.java
 * 
 * Modified on 26. 11. 2008
 */
package cz.muni.fi.pb162.traffic.network;

/**
 * Mass traffic network stop
 * @author oprendek
 */
public class Stop {

    private String name;

    /**
     * Creates a new instance of Stop
     * @param name stop's name
     * @throws NullPointerException if name is null
     * @throws IllegalArgumentException if name is an empty string
     */
    public Stop(String name) {
        if (name==null) {
            throw new NullPointerException("stop's name can not be null");
        }
        if ("".equals(name)) {
            throw new IllegalArgumentException("stop's name can not be empty");
        }
        this.name = name;
    }

    /**
     * Gives the name of the stop
     * @return stop's name
     */
    public String getName() {
        return name;
    }

    /**
     * Renames the stop
     * @param name stop's new name
     */
    public void setName(String name) {
        this.name = name;
    }

    @Override
    /**
     * Indicates whether some other stop is "equal to" this one, what means, has the same name
     * @param obj the reference object with which to compare.
     * @return <code>true</code> if this object has the same no as the obj
     *          argument; <code>false</code> otherwise.
     */
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Stop other = (Stop) obj;
        if (this.name != other.name && (this.name == null || !this.name.equals(other.name))) {
            return false;
        }
        return true;
    }

    @Override
    /**
     * Returns a hash code value for the object computed from the "name" parameter.
     *
     * @return a hash code value for this object.
     */
    public int hashCode() {
        int hash = 7;
        hash = 97 * hash + (this.name != null ? this.name.hashCode() : 0);
        return hash;
    }

    /**
     * Gives the basic information about the stop
     * @return text information about the stop
     */
    @Override
    public String toString() {
        return "Stop " + name;
    }
}
